// Fetch data from the CSV file using d3.js
d3.csv(
  'https://gist.githubusercontent.com/Rekha-Telkapally/5fd9c2248db0d83914450969765eb54e/raw/add163ad80b6b4495f7713a1fc717d57f291c110/MobilePhones.csv',
).then((data) => {
  const brands = {};

  // Parse CSV data and aggregate sales by brand using D3.js
  data.forEach((row) => {
    const brand = row.Brand;
    const sales = +row.Sales;
    brands[brand] = (brands[brand] || 0) + sales;
  });

  // Extract brand names and sales values
  const brandNames = Object.keys(brands);
  const salesValues = Object.values(brands);

  // Generate random colors for each brand
  const randomColor = () => Math.floor(Math.random() * 255);
  const backgroundColors = brandNames.map(
    () =>
      `rgba(${randomColor()}, ${randomColor()}, ${randomColor()}, 0.2)`,
  );
  const borderColors = brandNames.map(
    () =>
      `rgba(${randomColor()}, ${randomColor()}, ${randomColor()}, 1)`,
  );

  // Create a line chart using Chart.js
  const ctx = document
    .getElementById('myChart')
    .getContext('2d');
  const myChart = new Chart(ctx, {
    type: 'line',
    data: {
      labels: brandNames,
      datasets: [
        {
          label: 'Average Sales',
          data: salesValues,
          backgroundColor: backgroundColors,
          borderColor: borderColors,
          borderWidth: 4,
          fill: true,
        },
      ],
    },
    options: {
      plugins: {
        title: {
          display: true,
          text: 'Average Sales of all Brands - Area Chart',
          color: 'Green',
          font: {
            size: 20,
          },
        },
      },
      scales: {
        x: {
          title: {
            display: true,
            text: 'Brand',
            color: 'Green',
            font: {
              size: 20,
            },
          },
        },
        y: {
          title: {
            display: true,
            text: 'Total Sales',
            color: 'Green',
            font: {
              size: 20,
            },
          },
        },
      },
    },
  });
});
